==> haskell-monad-journal-0.8.1-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-1sjBzfDMtATIU65C4qlRg8
key: monad-journal-0.8.1-1sjBzfDMtATIU65C4qlRg8
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: ab6626f711daac51c647cb21d5a2a4df
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-1sjBzfDMtATIU65C4qlRg8
depends:
    base-4.11.1.0 mtl-2.2.2 transformers-0.5.5.0
    monad-control-1.0.2.3-LF1NHBZIRgG6fG7d7ZwfSq
    transformers-base-0.4.5.2-DJGvQweLM1lBYaWuB3tp04
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             monad-control-1.0.2.3-LF1NHBZIRgG6fG7d7ZwfSq=a47d843a3db6efd069d92470c607da07
             transformers-base-0.4.5.2-DJGvQweLM1lBYaWuB3tp04=a3f67982300e89309c37d8cba5c70df6
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-K81kvdSxQbKLwMxmGBpSFH
key: monad-journal-0.8.1-K81kvdSxQbKLwMxmGBpSFH
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: e9d60324cefa9346b2e6dcac3ea7ea98
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.6.1/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-K81kvdSxQbKLwMxmGBpSFH
depends:
    base-4.12.0.0 monad-control-1.0.2.3-E1ObyzwIT2xCXzhuW7Govm
    mtl-2.2.2 transformers-0.5.5.0
    transformers-base-0.4.5.2-1DiUF50wDMZ8pcSXqSIOuW
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
